@@ -455,7 +455,7 @@ class MainWindow( object ):
                 self.plugins["applications"].changeTab(0)
             self.plugins["applications"].focusSearchEntry()
 
-    def hide( self, forceHide = False ):
+    def hide( self ):
         for plugin in self.plugins.values():
             if hasattr( plugin, "onHideMenu" ):
                 plugin.onHideMenu()
@@ -697,15 +697,15 @@ class MenuWin( object ):
         self.button_icon.size_request(bi_req)
         self.systemlabel.size_request(sl_req)
         if self.applet.get_orient() == MatePanelApplet.AppletOrient.UP or self.applet.get_orient() == MatePanelApplet.AppletOrient.DOWN:
-           if self.hideIcon:
-               self.applet.set_size_request( sl_req.width + 2, bi_req.height )
-           else:
-               self.applet.set_size_request( sl_req.width + bi_req.width + 5, bi_req.height )
+            if self.hideIcon:
+                self.applet.set_size_request( sl_req.width + 2, bi_req.height )
+            else:
+                self.applet.set_size_request( sl_req.width + bi_req.width + 5, bi_req.height )
         else:
-           if self.hideIcon:
-               self.applet.set_size_request( bi_req.width, sl_req.height + 2 )
-           else:
-               self.applet.set_size_request( bi_req.width, sl_req.height + bi_req.height + 5 )
+            if self.hideIcon:
+                self.applet.set_size_request( bi_req.width, sl_req.height + 2 )
+            else:
+                self.applet.set_size_request( bi_req.width, sl_req.height + bi_req.height + 5 )
 
     def reloadSettings( self, *args ):
         self.loadSettings()
@@ -752,11 +752,11 @@ class MenuWin( object ):
             self.create_menu()
         # allow middle click and drag
         elif event.button == 2:
-            self.mainwin.hide( True )
+            self.mainwin.hide()
 
     def toggleMenu( self ):
         if self.applet.state & Gtk.StateType.SELECTED:
-            self.mainwin.hide( True )
+            self.mainwin.hide()
         else:
             self.positionMenu()
             self.mainwin.show()
