@@ -69,7 +69,8 @@ class mintMenuConfig( object ):
 
         self.builder.get_object("colorsLabel").set_text(_("Theme"))
         self.builder.get_object("favLabel").set_text(_("Favorites"))
-        self.builder.get_object("label3").set_text(_("Main button"))
+        self.builder.get_object("mainbuttonLabel").set_text(_("Main button"))
+        self.builder.get_object("pluginsLabel").set_text(_("Plugins"))
 
         self.builder.get_object("backgroundColorLabel").set_text(_("Background:"))
         self.builder.get_object("headingColorLabel").set_text(_("Headings:"))
@@ -284,7 +285,7 @@ class mintMenuConfig( object ):
         model = Gtk.ListStore(str, str)
         self.builder.get_object("themesCombo").set_model(model)
         selected_theme = model.append([_("Desktop theme"), "default"])
-        for theme in themes:
+        for theme in sorted(themes):
             if theme.startswith("/usr/share/themes") and theme.endswith("/gtk-2.0/gtkrc"):
                 theme = theme.replace("/usr/share/themes/", "")
                 theme = theme.replace("gtk-2.0", "")
