@@ -1,7 +1,6 @@
 #!/usr/bin/python
 
 import os
-import subprocess
 
 def RemoveArgs(Execline):
 	NewExecline = []
@@ -24,7 +23,7 @@ def Execute( cmd , commandCwd=None):
 			cwd = tmpCwd
 	
 	if isinstance( cmd, str ) or isinstance( cmd, unicode):
-		if (cmd.find("/home/") >= 0) or (cmd.find("su-to-root") >= 0) or (cmd.find("\"") >= 0):
+		if (cmd.find("ubiquity") >= 0) or (cmd.find("/home/") >= 0) or (cmd.find("su-to-root") >= 0) or (cmd.find("\"") >= 0):
 			print "running manually..."
 			try:
 				os.chdir(cwd)
@@ -40,7 +39,6 @@ def Execute( cmd , commandCwd=None):
 		os.chdir( cwd )
 		string = ' '.join(cmd)
 		string = string + " &"
-		#subprocess.Popen( cmd ) // use os.system instead of popen so children don't end up in zombie waiting for us to wait() for them
 		os.system(string)		
 		return True
 	except Exception, detail:
